@@ -8,13 +8,13 @@ use 5.010001;
 use Carp qw(croak);
 use Archive::Tar;
 use File::Spec::Functions qw(file_name_is_absolute rel2abs);
-use File::Basename qw(dirname fileparse);
+use File::Basename qw(basename dirname fileparse);
 use File::Path qw(make_path);
 use MIME::Base64 qw(decode_base64);
 use IO::Uncompress::Gunzip;
 use HTTP::Tiny;
 
-our $VERSION = "0.9";
+our $VERSION = "0.91";
 
 =pod
 
@@ -127,7 +127,9 @@ sub import {
             : ( $entry eq '__DATA__' ) ? _get_data($caller_file)
             :                            _get_files( $entry, $caller_file );
         for my $arc (@$arcs) {
-            my $path = $is_url ? $entry : $arc->[0];
+            my $path  = $is_url ? $entry : $arc->[0];
+            my $base  = basename($path);
+            my @ver   = $base =~ /(v?\d+\.\d+(?:\.\d+)?)/gi;
             my %tmp;
             my $mod = 0;
             my $lib = 0;
@@ -141,7 +143,7 @@ sub import {
             }
             for my $rel ( keys %tmp ) {
                 my $full = join( '/', $mod ? $arc->[1] : (), $lib ? 'lib' : (), $rel );
-                $cache{$rel} //= { path => "$path/$full", content => $tmp{$rel}{$full} };
+                $cache{$rel} //= { path => "$path/$full", content => $tmp{$rel}{$full}, arcver => $ver[-1] // '' };
             }
         }
     }
@@ -149,7 +151,7 @@ sub import {
     unshift @INC, sub {
         my ( $cref, $rel ) = @_;
         return unless my $rec = $cache{$rel};
-        $INC{$rel} = _expand( $rel, $rec->{content} ) if $ENV{PERL_LIB_ARCHIVE_EXTRACT};
+        $INC{$rel} = _expand( $rel, $rec->{content}, $rec->{arcver} ) if $ENV{PERL_LIB_ARCHIVE_EXTRACT};
         $INC{$rel} //= $rec->{path} unless defined($DB::single);
         open( my $pfh, '<', $rec->{content} ) or croak $!;    ## no critic (RequireBriefOpen)
         return $pfh;
@@ -161,7 +163,7 @@ sub import {
 
 sub _get_files {
     my ( $glob, $cfile ) = @_;
-    ( my $glob_ux = $glob )                      =~ s!\\!/!g;
+    ( my $glob_ux = $glob ) =~ s!\\!/!g;
     ( my $cdir    = dirname( rel2abs($cfile) ) ) =~ s!\\!/!g;
     $glob_ux = "$cdir/$glob_ux" unless file_name_is_absolute($glob_ux);
     my @files;
@@ -220,8 +222,8 @@ sub _get_data {
 
 
 sub _expand {
-    my ( $rel, $cref ) = @_;
-    my $fn = "$ENV{PERL_LIB_ARCHIVE_EXTRACT}/$rel";
+    my ( $rel, $cref, $ver ) = @_;
+    my $fn = $ver ? "$ENV{PERL_LIB_ARCHIVE_EXTRACT}/$ver/$rel" : "$ENV{PERL_LIB_ARCHIVE_EXTRACT}/$rel";
     make_path( dirname($fn) );
     open( my $fh, '>', $fn ) or die "couldn't save $fn, $!\n";
     print $fh $$cref;
